@@ -1,7 +1,7 @@
 /*============================================================================
 
-  WCSLIB 4.13 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2012, Mark Calabretta
+  WCSLIB 4.18 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2013, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -16,18 +16,12 @@
   more details.
 
   You should have received a copy of the GNU Lesser General Public License
-  along with WCSLIB.  If not, see <http://www.gnu.org/licenses/>.
+  along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Correspondence concerning WCSLIB may be directed to:
-    Internet email: mcalabre@atnf.csiro.au
-    Postal address: Dr. Mark Calabretta
-                    Australia Telescope National Facility, CSIRO
-                    PO Box 76
-                    Epping NSW 1710
-                    AUSTRALIA
+  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
 
-  Author: Mark Calabretta, Australia Telescope National Facility
-  http://www.atnf.csiro.au/~mcalabre/index.html
+  Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
+  http://www.atnf.csiro.au/people/Mark.Calabretta
   $Id$
 *===========================================================================*/
 
@@ -202,13 +196,13 @@ int spcprt(const struct spcprm *spc)
   }
 
   wcsprintf("     spxX2P: %s\n",
-    wcsutil_fptr2str((int (*)())spc->spxX2P, hext));
+    wcsutil_fptr2str((int (*)(void))spc->spxX2P, hext));
   wcsprintf("     spxP2S: %s\n",
-    wcsutil_fptr2str((int (*)())spc->spxP2S, hext));
+    wcsutil_fptr2str((int (*)(void))spc->spxP2S, hext));
   wcsprintf("     spxS2P: %s\n",
-    wcsutil_fptr2str((int (*)())spc->spxS2P, hext));
+    wcsutil_fptr2str((int (*)(void))spc->spxS2P, hext));
   wcsprintf("     spxP2X: %s\n",
-    wcsutil_fptr2str((int (*)())spc->spxP2X, hext));
+    wcsutil_fptr2str((int (*)(void))spc->spxP2X, hext));
 
   return SPCERR_SUCCESS;
 }
@@ -729,6 +723,8 @@ int spctype(
   char ctype[9], ptype_t, sname_t[32], units_t[8], xtype_t;
   int  restreq_t = 0;
 
+  if (err) *err = 0x0;
+
   /* Copy with blank padding. */
   sprintf(ctype, "%-8.8s", ctypei);
   ctype[8] = '\0';
@@ -936,6 +932,7 @@ int spcspxe(
   if ((status = specx(type, crvalS, restfrq, restwav, &spx))) {
     status = SPCERR_BAD_SPEC_PARAMS;
     if (err) {
+      *err = spx.err;
       (*err)->status = status;
     } else {
       free(spx.err);
@@ -1116,6 +1113,7 @@ int spcxpse(
   if (specx(type, crvalX, restfrq, restwav, &spx)) {
     status = SPCERR_BAD_SPEC_PARAMS;
     if (err) {
+      *err = spx.err;
       (*err)->status = status;
     } else {
       free(spx.err);
@@ -1252,7 +1250,7 @@ int spctrne(
   static const char *function = "spctrne";
 
   char *cp, ptype1, ptype2, stype1[5], stype2[5], xtype1, xtype2;
-  int  restreq;
+  int  restreq, status;
   double crvalX, dS2dX, dXdS1;
 
   if (restfrq == 0.0 && restwav == 0.0) {
@@ -1268,9 +1266,9 @@ int spctrne(
     }
   }
 
-  if (spcspxe(ctypeS1, crvalS1, restfrq, restwav, &ptype1, &xtype1,
-              &restreq, &crvalX, &dXdS1, err)) {
-    return (*err)->status;
+  if ((status = spcspxe(ctypeS1, crvalS1, restfrq, restwav, &ptype1, &xtype1,
+                        &restreq, &crvalX, &dXdS1, err))) {
+    return status;
   }
 
   /* Pad with blanks. */
@@ -1290,9 +1288,9 @@ int spctrne(
     }
   }
 
-  if (spcxpse(ctypeS2, crvalX, restfrq, restwav, &ptype2, &xtype2,
-              &restreq, crvalS2, &dS2dX, err)) {
-    return (*err)->status;
+  if ((status = spcxpse(ctypeS2, crvalX, restfrq, restwav, &ptype2, &xtype2,
+                        &restreq, crvalS2, &dS2dX, err))) {
+    return status;
   }
 
   /* Are the X-types compatible? */
